@@ -8,7 +8,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /home/projects/pgsql/cvsroot/pgsql/src/backend/parser/parse_oper.c,v 1.48 2001/03/22 03:59:41 momjian Exp $
+ *	  $Header: /home/projects/pgsql/cvsroot/pgsql/src/backend/parser/parse_oper.c,v 1.49 2001/04/23 04:32:30 tgl Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -686,6 +686,9 @@ compatible_oper(char *op, Oid arg1, Oid arg2, bool noError)
 		 IS_BINARY_COMPATIBLE(opform->oprright, arg2)))
 		return optup;
 
+	/* nope... */
+	ReleaseSysCache(optup);
+
 	if (!noError)
 		op_error(op, arg1, arg2);
 
